@@ -91,7 +91,7 @@ typedef struct
 
 /*
  * Each block holds several "cache item", which consists of variable
- * length of Data(header plus RowDescription packet and DataRow
+ * length of Data (header plus RowDescription packet and DataRow
  * packet).  Each cache item is assigned "cache item id", which
  * represents the cache item order in a block.
  */
@@ -104,12 +104,13 @@ typedef struct
 
 /*
  * "Cache Item header" structure is used to manage each cache item.
- *  (12 bytes)
+ *  (16 bytes)
  */
 typedef struct
 {
 	unsigned int total_length;	/* total length in bytes including myself */
 	time_t		timestamp;		/* cache creation time */
+	int			expire;			/* cache expire	duration in seconds */
 }			POOL_CACHE_ITEM_HEADER;
 
 typedef struct
@@ -244,6 +245,9 @@ extern POOL_STATUS pool_fetch_from_memory_cache(POOL_CONNECTION * frontend,
 												POOL_CONNECTION_POOL * backend,
 												char *contents, bool *foundp);
 
+extern int pool_fetch_cache(POOL_CONNECTION_POOL * backend, const char *query, char **buf, size_t *len);
+extern int pool_catalog_commit_cache(POOL_CONNECTION_POOL * backend, char *query, char *data, size_t datalen);
+
 extern bool pool_is_likely_select(char *query);
 extern bool pool_is_table_in_black_list(const char *table_name);
 extern bool pool_is_table_in_white_list(const char *table_name);
@@ -284,7 +288,6 @@ extern void pool_discard_temp_query_cache(POOL_TEMP_QUERY_CACHE * temp_cache);
 
 extern void pool_shmem_lock(void);
 extern void pool_shmem_unlock(void);
-
-extern void pool_init_whole_cache_blocks(void);
+extern bool pool_is_shmem_lock(void);
 
 #endif							/* POOL_MEMQCACHE_H */
